summaryrefslogtreecommitdiffstats
path: root/kmail/headeritem.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/headeritem.cpp')
-rw-r--r--kmail/headeritem.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/kmail/headeritem.cpp b/kmail/headeritem.cpp
index 7742e3ba..81a4252c 100644
--- a/kmail/headeritem.cpp
+++ b/kmail/headeritem.cpp
@@ -42,8 +42,8 @@
using namespace KMail;
// Constuction a new list view item with the given colors and pixmap
-HeaderItem::HeaderItem( TQListView* tqparent, int msgId, const TQString& key )
- : KListViewItem( tqparent ),
+HeaderItem::HeaderItem( TQListView* parent, int msgId, const TQString& key )
+ : KListViewItem( parent ),
mMsgId( msgId ),
mKey( key ),
mAboutToBeDeleted( false ),
@@ -52,9 +52,9 @@ HeaderItem::HeaderItem( TQListView* tqparent, int msgId, const TQString& key )
irefresh();
}
-// Constuction a new list view item with the given tqparent, colors, & pixmap
-HeaderItem::HeaderItem( TQListViewItem* tqparent, int msgId, const TQString& key )
- : KListViewItem( tqparent ),
+// Constuction a new list view item with the given parent, colors, & pixmap
+HeaderItem::HeaderItem( TQListViewItem* parent, int msgId, const TQString& key )
+ : KListViewItem( parent ),
mMsgId( msgId ),
mKey( key ),
mAboutToBeDeleted( false ),
@@ -92,7 +92,7 @@ void HeaderItem::irefresh()
return; //default to closed
// otherwise threadingPolicy == OpenUnread
- if (tqparent() && tqparent()->isOpen()) {
+ if (parent() && parent()->isOpen()) {
setOpen(true);
return;
}
@@ -103,8 +103,8 @@ void HeaderItem::irefresh()
|| mMsgBase->isImportant() || mMsgBase->isTodo() || mMsgBase->isWatched() ) {
setOpen(true);
HeaderItem * topOfThread = this;
- while(topOfThread->tqparent())
- topOfThread = (HeaderItem*)topOfThread->tqparent();
+ while(topOfThread->parent())
+ topOfThread = (HeaderItem*)topOfThread->parent();
topOfThread->setOpenRecursive(true);
}
}
@@ -198,7 +198,7 @@ TQString HeaderItem::text( int col) const
tmp = headers->mDate.dateString( mMsgBase->date() );
} else if(col == headers->paintInfo()->sizeCol
&& headers->paintInfo()->showSize) {
- if ( mMsgBase->tqparent()->folderType() == KMFolderTypeImap ) {
+ if ( mMsgBase->parent()->folderType() == KMFolderTypeImap ) {
tmp = KIO::convertSize( mMsgBase->msgSizeServer() );
} else {
tmp = KIO::convertSize( mMsgBase->msgSize() );
@@ -232,17 +232,17 @@ TQPixmap HeaderItem::pixmapMerge( PixmapList pixmaps ) const
}
TQPixmap res( width, height );
- TQBitmap tqmask( width, height, true );
+ TQBitmap mask( width, height, true );
int x = 0;
for ( PixmapList::ConstIterator it = pixmaps.begin();
it != pixmaps.end(); ++it ) {
bitBlt( &res, x, (height - (*it).height()) / 2, &(*it) );
- bitBlt( &tqmask, x, (height - (*it).height()) / 2, (*it).tqmask() );
+ bitBlt( &mask, x, (height - (*it).height()) / 2, (*it).mask() );
x += (*it).width();
}
- res.setMask( tqmask );
+ res.setMask( mask );
return res;
}
@@ -490,7 +490,7 @@ TQString HeaderItem::generate_key( KMHeaders *headers,
}
else if (column == paintInfo->sizeCol) {
TQString len;
- if ( msg->tqparent()->folderType() == KMFolderTypeImap )
+ if ( msg->parent()->folderType() == KMFolderTypeImap )
{
len = TQString::number( msg->msgSizeServer() );
} else {
@@ -603,7 +603,7 @@ int HeaderItem::compare( TQListViewItem *i, int col, bool ascending ) const
res = key( col, ascending ).compare( i->key( col, ascending ) );
} else if ( col == headers->paintInfo()->dateCol ) {
res = key( col, ascending ).compare( i->key( col, ascending ) );
- if (i->tqparent() && !ascending)
+ if (i->parent() && !ascending)
res = -res;
} else if ( col == headers->paintInfo()->subCol ||
col == headers->paintInfo()->senderCol ||